"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var Api_1 = require("./Api");
var ApiChild = (function (_super) {
    __extends(ApiChild, _super);
    function ApiChild() {
        return _super.apply(this, arguments) || this;
    }
    return ApiChild;
}(Api_1.default));
describe('Api', function () {
    var api;
    beforeEach(function () {
        api = new ApiChild();
    });
    it('should assign properties on construct', function () {
        var cacheless = new Api_1.default({ usePromiseCache: false });
        expect(Api_1.default.usePromiseCache).toBeTruthy();
        expect(cacheless.usePromiseCache).toBeFalsy();
    });
    it('should resolve instance base', function () {
        api.base = 'instance base';
        expect(api.resolveBase()).toBe('instance base');
    });
    it('should return empty path by default', function () {
        expect(api.path()).toBe('');
    });
    it('should resolve class static base', function () {
        ApiChild.base = 'child';
        expect(api.resolveBase()).toBe('child');
    });
    it('should resolve Api static base', function () {
        Api_1.default.base = 'api';
        ApiChild.base = null;
        expect(api.resolveBase()).toBe('api');
    });
    it('should resolve instance headers', function () {
        api.headers = 'headers';
        expect(api.resolveHeaders()).toBe('headers');
    });
    it('should resolve class static headers', function () {
        ApiChild.headers = 'child';
        expect(api.resolveHeaders()).toBe('child');
    });
    it('should resolve Api static headers', function () {
        Api_1.default.headers = 'api';
        ApiChild.headers = null;
        expect(api.resolveHeaders()).toBe('api');
    });
    it('should get base url', function () {
        api.resolveBase = function () { return 'base'; };
        api.path = function () { return 'path'; };
        expect(api.baseUrl()).toBe('base/path/');
    });
    it('should not be using cache', function () {
        api.useCache = false;
        ApiChild.useCache = false;
        Api_1.default.useCache = false;
        expect(api.isUsingCache()).toBeFalsy();
    });
    it('should be using instance cache', function () {
        api.useCache = true;
        ApiChild.useCache = false;
        Api_1.default.useCache = false;
        expect(api.isUsingCache()).toBeTruthy();
    });
    it('should be using class static cache', function () {
        api.useCache = false;
        ApiChild.useCache = true;
        Api_1.default.useCache = false;
        expect(api.isUsingCache()).toBeTruthy();
    });
    it('should be using Api static cache', function () {
        api.useCache = false;
        ApiChild.useCache = false;
        Api_1.default.useCache = true;
        expect(api.isUsingCache()).toBeTruthy();
    });
    it('should not be using promise cache', function () {
        api.usePromiseCache = false;
        ApiChild.usePromiseCache = false;
        Api_1.default.usePromiseCache = false;
        expect(api.isUsingPromiseCache()).toBeFalsy();
    });
    it('should be using promise instance cache', function () {
        api.usePromiseCache = true;
        ApiChild.usePromiseCache = false;
        Api_1.default.usePromiseCache = false;
        expect(api.isUsingPromiseCache()).toBeTruthy();
    });
    it('should be using class static promise cache', function () {
        api.usePromiseCache = false;
        ApiChild.usePromiseCache = true;
        Api_1.default.usePromiseCache = false;
        expect(api.isUsingPromiseCache()).toBeTruthy();
    });
    it('should be using Api static promise cache', function () {
        api.usePromiseCache = false;
        ApiChild.usePromiseCache = false;
        Api_1.default.usePromiseCache = true;
        expect(api.isUsingPromiseCache()).toBeTruthy();
    });
    it('should get http instance with baseUrl and headers', function () {
        api.baseUrl = function () { return 'baseUrl'; };
        api.resolveHeaders = function () { return ({ 'customHeader': 'value' }); };
        var http = api.http();
        expect(http.defaults.headers['customHeader']).toBe('value');
        expect(http.defaults.baseURL).toBe(api.baseUrl());
    });
    it('should not check cache with usePromiseCache set to false', function () {
        api.isUsingPromiseCache = function () { return false; };
        var promise = 'cached';
        api.cache.setPromise('promise', promise);
        expect(api.cachePromise('promise', jest.fn())).not.toBe(promise);
    });
    it('should get cached promise', function () {
        api.cache.setPromise('promise', 'cached');
        expect(api.cachePromise('promise', jest.fn())).toBe('cached');
    });
    it('should create new promise and add to cache', function () {
        var promise = api.cachePromise('promise', jest.fn());
        expect(api.cachePromise('promise', jest.fn)).toBe(promise);
    });
    it('should set jwt token', function () {
        Api_1.default.headers = {};
        Api_1.default.setJwtToken('jwt');
        expect(api.resolveHeaders()['Authorization']).toBe('Bearer jwt');
    });
    it('should remove jwt token', function () {
        Api_1.default.headers = {};
        Api_1.default.setJwtToken('jwt');
        Api_1.default.removeJwtToken();
        expect(api.resolveHeaders()['Authorization']).toBeUndefined();
    });
    it('should set csrf token', function () {
        Api_1.default.headers = {};
        Api_1.default.setCsrfToken('csrf');
        expect(api.resolveHeaders()['X-CSRF-Token']).toBe('csrf');
    });
    it('should remove csrf token', function () {
        Api_1.default.headers = {};
        Api_1.default.setCsrfToken('csrf');
        Api_1.default.removeCsrfToken();
        expect(api.resolveHeaders()['X-CSRF-Token']).toBeUndefined();
    });
});
//# sourceMappingURL=Api.spec.js.map