import Api from './Api';
import { Promise } from 'axios';
import { IModel } from './Model';
import Hash from './Hash';
/**
 * The cache is responsible for storing objects, lists and promises
 * The goal is to optimize the application speed and network usage
 */
export default class Cache {
    /**
     * The Api associated with the cache.
     */
    api: Api;
    /**
     * The list of objects cached.
     */
    objects: Hash<IModel>;
    /**
     * The list of lists of object cached.
     */
    lists: Hash<IModel[]>;
    /**
     * The list of promises cached.
     */
    promises: Hash<Promise<any>>;
    constructor(api: Api);
    /**
     * Get key from value
     */
    static resolveKey(value: any | IModel): string;
    /**
     * Check if caching is enabled
     */
    enabled(): boolean;
    /**
     * Check if promise caching is enabled
     */
    promiseEnabled(): boolean;
    /**
     * Get object
     */
    get(value: any): IModel;
    /**
     * Get object by property value
     */
    where(property: string, value: any): IModel;
    /**
     * Set object
     */
    set(value: IModel | IModel[], clearLists?: boolean): IModel | IModel[];
    /**
     * Remove object
     */
    destroy(value: string | IModel): void;
    /**
     * Get list by name
     */
    getList(name: string): IModel[];
    /**
     * Set list by name
     */
    setList(name: string, list: IModel[]): IModel[];
    destroyList(name: string): void;
    /**
     * Get promise by name
     */
    getPromise(name: string): Promise<any>;
    /**
     * Set promise by name
     */
    setPromise(name: string, promise: Promise<any>): Promise<any>;
    /**
     * Destroy promise by name
     */
    destroyPromise(name: string): void;
}
