"use strict";
var Cache_1 = require("./Cache");
var Api_1 = require("./Api");
describe('Cache', function () {
    var cache;
    var model;
    var list;
    var promise = 'promise instance';
    beforeEach(function () {
        cache = new Cache_1.default(new Api_1.default());
        model = { key: jest.fn().mockReturnValue('id') };
        list = [model];
    });
    it('should resolve key from object', function () {
        expect(Cache_1.default.resolveKey(model)).toBe('id');
    });
    it('should resolve key from value', function () {
        expect(Cache_1.default.resolveKey(1)).toBe('1');
    });
    it('should be enabled without api', function () {
        cache.api = null;
        expect(cache.enabled()).toBeTruthy();
    });
    it('should be enabled with api cache enabled', function () {
        cache.api.isUsingCache = function () { return true; };
        expect(cache.enabled()).toBeTruthy();
    });
    it('should not be enabled with api cache disabled', function () {
        cache.api.isUsingCache = function () { return false; };
        expect(cache.enabled()).toBeFalsy();
    });
    it('should have promise enabled without api', function () {
        cache.api = null;
        expect(cache.promiseEnabled()).toBeTruthy();
    });
    it('should have promise enabled with api promise cache enabled', function () {
        cache.api.isUsingPromiseCache = function () { return true; };
        expect(cache.promiseEnabled()).toBeTruthy();
    });
    it('should not have promise enabled with api promise cache disabled', function () {
        cache.api.isUsingPromiseCache = function () { return false; };
        expect(cache.promiseEnabled()).toBeFalsy();
    });
    it('should get object with key', function () {
        cache.set(model);
        expect(cache.get('id')).toBe(model);
    });
    it('should not get object when disabled', function () {
        cache.enabled = function () { return false; };
        cache.set(model);
        expect(cache.get('id')).toBeUndefined();
    });
    it('should find object value', function () {
        model['property'] = 'value';
        cache.set(model);
        expect(cache.where('property', 'value')).toBe(model);
    });
    it('should not find object when disabled', function () {
        cache.set(model);
        cache.enabled = function () { return false; };
        expect(cache.get('id')).toBeUndefined();
    });
    it('should destroy with key', function () {
        cache.set(model);
        cache.destroy('id');
        expect(cache.get('id')).toBeUndefined();
    });
    it('should destroy with object', function () {
        cache.set(model);
        cache.destroy(model);
        expect(cache.get('id')).toBeUndefined();
    });
    it('should clear lists after destroying', function () {
        cache.lists = 'lists';
        cache.set(model);
        cache.destroy(model);
        expect(cache.lists).toEqual({});
    });
    it('should set list', function () {
        cache.setList('list', list);
        expect(cache.lists['list']).toBe(list);
    });
    it('should get list', function () {
        cache.setList('list', list);
        expect(cache.getList('list')).toBe(list);
    });
    it('should destroy list', function () {
        cache.setList('list', list);
        cache.destroyList('list');
        expect(cache.getList('list')).toBeUndefined();
    });
    it('should set promise', function () {
        cache.setPromise('promise', promise);
        expect(cache.promises['promise']).toBe(promise);
    });
    it('should get promise', function () {
        cache.setPromise('promise', promise);
        expect(cache.getPromise('promise')).toBe(promise);
    });
    it('should destroy promise', function () {
        cache.setPromise('promise', promise);
        cache.destroyPromise('promise');
        expect(cache.getPromise('promise')).toBeUndefined();
    });
});
//# sourceMappingURL=Cache.spec.js.map