"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var Model_1 = require("./Model");
var Store_1 = require("./Store");
var SpecModel = (function (_super) {
    __extends(SpecModel, _super);
    function SpecModel() {
        var _this = _super.apply(this, arguments) || this;
        _this.id = 1;
        _this.property = 'value';
        return _this;
    }
    SpecModel.normalize_property = function (value) {
        return 'normalized ' + value;
    };
    SpecModel.denormalize_property = function (value) {
        return 'denormalized ' + value;
    };
    return SpecModel;
}(Model_1.default));
SpecModel.singular = 'spec';
var SpyModel = (function (_super) {
    __extends(SpyModel, _super);
    function SpyModel() {
        var _this = _super.apply(this, arguments) || this;
        _this.id = 'spy';
        return _this;
    }
    return SpyModel;
}(Model_1.default));
describe('Store foreign method', function () {
    var model;
    var spyModel;
    var store = SpecModel.resolveStore();
    ['index', 'get', 'where', 'create', 'update', 'by', 'foreign', 'destroy', 'act'].forEach(function (key) {
        store[key] = jest.fn().mockReturnValue({ then: jest.fn() });
    });
    beforeEach(function () {
        model = new SpecModel();
        spyModel = new SpyModel();
        ['find', 'save', 'destroy', 'belongsToMany', 'hasOne', 'hasMany', 'act'].forEach(function (key) { return SpyModel[key] = jest.fn(); });
    });
    it('should get store', function () {
        expect(model.store()).toBeInstanceOf(Store_1.default);
    });
    it('should resolve creating store', function () {
        SpyModel.store = 'store';
        expect(SpyModel.resolveStore()).toBe('store');
    });
    it('should resolve new store', function () {
        SpyModel.store = null;
        SpyModel.createStore = jest.fn();
        SpyModel.resolveStore('properties');
        expect(SpyModel.createStore).toHaveBeenCalledWith('properties');
    });
    it('should create store', function () {
        expect(SpecModel.createStore()).toBeInstanceOf(Store_1.default);
    });
    it('should create store with properties', function () {
        var store = SpecModel.createStore({ property: 'value' });
        expect(store.property).toBe('value');
    });
    it('should get key', function () {
        expect(model.key()).toBe(1);
    });
    it('should map', function () {
        expect(model.map()).toEqual({ id: 1, property: 'denormalized value' });
    });
    it('should get foreign key', function () {
        SpyModel.singular = 'spy';
        model.spy_id = 'fk';
        expect(model.foreignKey(SpyModel)).toBe('fk');
    });
    it('should get foreign key name', function () {
        expect(SpecModel.foreignKey()).toBe('spec_id');
    });
    it('should resolve normalizer', function () {
        expect(SpecModel.resolveTransformer('property')).toBe('normalize_property');
    });
    it('should resolve denormalizer', function () {
        expect(SpecModel.resolveTransformer('property', 'denormalize')).toBe('denormalize_property');
    });
    it('should resolve camelCase normalizer', function () {
        SpyModel.normalize_my_property = null;
        SpyModel.normalizeMyProperty = jest.fn();
        expect(SpyModel.resolveTransformer('my_property')).toBe('normalizeMyProperty');
    });
    it('should normalize', function () {
        expect(SpecModel.normalize('property', 'value')).toBe('normalized value');
    });
    it('should denormalize', function () {
        expect(SpecModel.denormalize('property', 'value')).toBe('denormalized value');
    });
    it('should set', function () {
        SpyModel.normalize = jest.fn();
        expect(model.set({ property: 'set value' }).property).toBe('set value');
        expect(SpyModel.normalize).not.toHaveBeenCalled();
    });
    it('should set and normalize', function () {
        SpyModel.normalize = jest.fn();
        spyModel.set({ property: 'value' }, true);
        expect(SpyModel.normalize).toHaveBeenCalledWith('property', 'value');
    });
    it('should duplicate', function () {
        expect(model.duplicate()).toEqual({ id: 1, property: 'value' });
    });
    it('should make', function () {
        var model = SpecModel.make({ property: 'made value' });
        expect(model.property).toBe('made value');
    });
    it('should make and normalize', function () {
        SpyModel.normalize = jest.fn();
        SpyModel.make({ property: 'value' }, true);
        expect(SpyModel.normalize).toHaveBeenCalledWith('property', 'value');
    });
    it('should reload', function () {
        spyModel.reload();
        expect(SpyModel.find).toHaveBeenCalledWith('spy');
    });
    it('should find', function () {
        SpecModel.find(1, 'options');
        expect(model.store().get).toHaveBeenCalledWith(1, 'options');
    });
    it('should save', function () {
        spyModel.map = function () { return 'map'; };
        spyModel.save('options');
        expect(SpyModel.save).toHaveBeenCalledWith('map', 'options');
    });
    it('should create', function () {
        var data = { name: 'name' };
        SpecModel.save(data, 'options');
        expect(model.store().create).toHaveBeenCalledWith(data, 'options');
    });
    it('should update', function () {
        var data = { id: 1, name: 'name' };
        SpecModel.save(data, 'options');
        expect(model.store().update).toHaveBeenCalledWith(data, 'options');
    });
    it('should create statically', function () {
        var properties = { property: 'values' };
        SpecModel.save(properties, 'options');
        expect(store.create).toHaveBeenCalledWith(properties, 'options');
    });
    it('should update statically', function () {
        var properties = { id: 'id', property: 'values' };
        SpecModel.save(properties, 'options');
        expect(store.update).toHaveBeenCalledWith(properties, 'options');
    });
    it('should save array statically', function () {
        expect(Array.isArray(SpecModel.save([1, 2]))).toBeTruthy();
    });
    it('should destroy', function () {
        spyModel.destroy('options');
        expect(SpyModel.destroy).toHaveBeenCalledWith('spy', 'options');
    });
    it('should destroy statically', function () {
        SpecModel.destroy(1, 'options');
        expect(model.store().destroy).toHaveBeenCalledWith(1, 'options');
    });
    it('should destroy array statically', function () {
        expect(Array.isArray(SpecModel.destroy([1, 1], 'options'))).toBeTruthy();
    });
    it('should belong to', function () {
        SpyModel.singular = 'spy';
        model.spy_id = 'fk';
        model.belongsTo(SpyModel, 'options');
        expect(SpyModel.find).toHaveBeenCalledWith('fk', 'options');
    });
    it('should belong to many', function () {
        spyModel.belongsToMany(SpecModel, 'options');
        expect(SpyModel.belongsToMany).toHaveBeenCalledWith(SpecModel, 'spy', 'options');
    });
    it('should belong to many statically', function () {
        SpecModel.belongsToMany(SpyModel, 'value', 'options');
        expect(model.store().foreign).toHaveBeenCalledWith(SpyModel, 'value', 'options');
    });
    it('should have one', function () {
        spyModel.hasOne(SpecModel, 'options');
        expect(SpyModel.hasOne).toHaveBeenCalledWith(SpecModel, 'spy', 'options');
    });
    it('should have one statically', function () {
        SpecModel.hasOne(SpyModel, 'value', 'options');
        expect(model.store().foreign).toHaveBeenCalledWith(SpyModel, 'value', 'options');
    });
    it('should have many', function () {
        spyModel.hasMany(SpecModel, 'options');
        expect(SpyModel.hasMany).toHaveBeenCalledWith(SpecModel, 'spy', 'options');
    });
    it('should have many statically', function () {
        SpecModel.hasMany(SpyModel, 'value', 'options');
        expect(model.store().foreign).toHaveBeenCalledWith(SpyModel, 'value', 'options');
    });
    it('should act', function () {
        spyModel.act('action', 'options');
        expect(SpyModel.act).toHaveBeenCalledWith('spy', 'action', 'options');
    });
    it('should act statically', function () {
        SpecModel.act('key', 'value', 'options');
        expect(model.store().act).toHaveBeenCalledWith('key', 'value', 'options');
    });
    it('should get by property', function () {
        SpecModel.where('property', 'value', 'options');
        expect(model.store().where).toHaveBeenCalledWith('property', 'value', 'options');
    });
    it('should fetch all', function () {
        SpecModel.all('options');
        expect(model.store().index).toHaveBeenCalledWith('options');
    });
    it('should get singular path', function () {
        expect(SpecModel.singularized()).toBe('spec');
    });
    it('should guess singular path', function () {
        SpyModel.singular = null;
        SpyModel.path = 'plurals';
        expect(SpyModel.singularized()).toBe('plural');
    });
});
//# sourceMappingURL=Model.spec.js.map