import Api from './Api';
import Model from './Model';
import Hash from './Hash';
export interface IStoreFetch {
    ignoreCache?: boolean;
    url?: string;
    permit?: boolean;
}
export interface IStoreSet {
    url?: string;
}
export interface IStoreForeign {
    ignoreCache?: boolean;
    url?: string;
    set?: boolean;
    permit?: boolean;
}
export interface IStoreAct {
    url?: string;
    data?: Hash<any>;
    method?: string;
    permit?: boolean;
}
/**
 * A Store is an Api that handles the requests for a given Model
 */
export default class Store<T> extends Api {
    /**
     * The model associated with the Store
     */
    model: typeof Model;
    /**
     * The default methods allowed by the store
     * If none given, all will be allowed
     */
    allows: String[];
    /**
     * The default methods denied by the store
     * If none given, all will be allowed
     */
    denies: String[];
    /**
     * If true, the results from `index` will be stored in the cache as objects
     */
    setIndex: boolean;
    constructor(model: typeof Model, properties?: Hash<any>);
    /**
     * @inheritDoc
     */
    path(): string;
    /**
     * Check if method is allowed
     */
    isMethodAllowed(method: string): boolean;
    /**
     * Verify if a method can be executed. If it can't, throw an error
     * @throws Error
     */
    verifyPermission(method: string): void;
    /**
     * Get new model instance
     */
    make(values: Hash<string>, normalize?: boolean): Model | Model[];
    /**
     * Get index
     */
    index(options?: IStoreFetch): Promise<T[]>;
    /**
     * Make http get request
     */
    get(key: any, options?: IStoreFetch): Promise<T>;
    /**
     * Make http get request to fetch by property
     */
    where(property: string, value: any, options?: IStoreFetch): Promise<T>;
    /**
     * Make http post request
     */
    create(data: Hash<any>, options?: IStoreSet): Promise<T>;
    /**
     * Make http put request
     */
    update(data: Hash<any>, options?: IStoreSet): Promise<T>;
    /**
     * Make http request to destroy model
     */
    destroy(value: Model | any, options?: IStoreSet): Promise<any>;
    /**
     * Call foreign method of store associated with given model
     */
    by(model: typeof Model, key: any, options?: IStoreForeign): Promise<T[]>;
    /**
     * Make http request to fetch instances by foreign key
     */
    foreign(model: typeof Model, key: any, options?: IStoreForeign): Promise<T[]>;
    /**
     * Make http to act
     */
    act(key: any, action: string, options?: IStoreAct): Promise<any>;
}
