"use strict";
var Store_1 = require("./Store");
var Model_1 = require("./Model");
describe('Store', function () {
    var store;
    var data = { property: 'value' };
    beforeEach(function () {
        store = new Store_1.default(Model_1.default);
    });
    it('should set model on construct', function () {
        expect(store.model).toBe(Model_1.default);
    });
    it('should set properties on construct', function () {
        var store = new Store_1.default(null, data);
        expect(store.property).toBe('value');
    });
    it('should get path from model', function () {
        store.model.path = 'path';
        expect(store.path()).toBe('path');
    });
    it('should be allowed to call method without restrictions set', function () {
        expect(store.isMethodAllowed('any')).toBeTruthy();
    });
    it('should not be allowed to call denied method', function () {
        store.denies = ['method'];
        expect(store.isMethodAllowed('method')).toBeFalsy();
    });
    it('should not be allowed to call method not in allowed list', function () {
        store.allows = ['method'];
        expect(store.isMethodAllowed('anotherMethod')).toBeFalsy();
    });
    it('should not throw exception verifying allowed method', function () {
        store.allows = ['method'];
        expect(function () { return store.verifyPermission('method'); }).not.toThrow();
    });
    it('should throw exception verifying forbidden method', function () {
        store.denies = ['method'];
        expect(function () { return store.verifyPermission('method'); }).toThrowError();
    });
    it('should make model with given values', function () {
        Model_1.default.make = jest.fn();
        store.make(data, 'normalize');
        expect(Model_1.default.make).toHaveBeenCalledWith(data, 'normalize');
    });
});
//# sourceMappingURL=Store.spec.js.map