"use strict";
var Helper_1 = require("./Helper");
var Store_1 = require("../Store");
describe('Store act method', function () {
    var store;
    beforeEach(function () {
        store = new Store_1.default(null);
        store.http = Helper_1.default.http(null);
    });
    it('should verify access', function () {
        store.denies = ['act'];
        expect(function () { return store.act(1, 'action'); }).toThrowError();
    });
    it('should skip access verification', function () {
        store.denies = ['act'];
        expect(function () { return store.act(1, 'action', { permit: true }); }).not.toThrow();
    });
    it('should make http request', function () {
        store.act(1, 'action');
        expect(store.http().put).toHaveBeenCalledWith('1/action', undefined);
    });
    it('should request with custom url', function () {
        store.act(1, 'action', { url: 'customUrl' });
        expect(store.http().put).toHaveBeenCalledWith('customUrl', undefined);
    });
    it('should request with given method', function () {
        store.act(1, 'action', { method: 'post' });
        expect(store.http().post).toHaveBeenCalledWith('1/action', undefined);
    });
    it('should request with data', function () {
        var data = { property: 'value' };
        store.act(1, 'action', { data: data });
        expect(store.http().put).toHaveBeenCalledWith('1/action', data);
    });
});
//# sourceMappingURL=Act.spec.js.map