"use strict";
var Helper_1 = require("./Helper");
var Store_1 = require("../Store");
describe('Store create method', function () {
    var store;
    var data = { name: 'name' };
    var responseData = { id: 1, name: 'name' };
    var instance = { key: function () { return responseData.id; } };
    beforeEach(function () {
        store = new Store_1.default(null);
        store.make = jest.fn().mockReturnValue(instance);
        store.http = Helper_1.default.http(responseData);
    });
    it('should verify access', function () {
        store.denies = ['create'];
        expect(function () { return store.create(data); }).toThrowError();
    });
    it('should make http request', function () {
        store.create(data);
        expect(store.http().post).toHaveBeenCalledWith('', data);
    });
    it('should request with custom url', function () {
        store.create(data, { url: 'customUrl' });
        expect(store.http().post).toHaveBeenCalledWith('customUrl', data);
    });
    it('should convert result to model instance', function () {
        store.create(data);
        expect(store.make).toHaveBeenCalledWith(responseData);
    });
    it('should add model to cache', function () {
        store.cache.set = jest.fn();
        store.create(data);
        expect(store.cache.set).toHaveBeenCalledWith(instance);
    });
    it('should resolve model instance', function () {
        store.index().then(function (result) {
            expect(result).toBe(instance);
        });
    });
});
//# sourceMappingURL=Create.spec.js.map