"use strict";
var Helper_1 = require("./Helper");
var Store_1 = require("../Store");
describe('Store destroy method', function () {
    var store;
    var instance = { key: function () { return 1; } };
    beforeEach(function () {
        store = new Store_1.default(null);
        store.http = Helper_1.default.http(null);
    });
    it('should verify access', function () {
        store.denies = ['destroy'];
        expect(function () { return store.destroy(1); }).toThrowError();
    });
    it('should make http request', function () {
        store.destroy(1);
        expect(store.http().delete).toHaveBeenCalledWith('1');
    });
    it('should destroy by object', function () {
        store.destroy(instance);
        expect(store.http().delete).toHaveBeenCalledWith('1');
    });
    it('should request with custom url', function () {
        store.destroy(1, { url: 'customUrl' });
        expect(store.http().delete).toHaveBeenCalledWith('customUrl');
    });
    it('should remove model to cache', function () {
        store.cache.set(instance);
        store.destroy(1);
        expect(store.cache.get(1)).toBeUndefined();
    });
});
//# sourceMappingURL=Destroy.spec.js.map