"use strict";
var Store_1 = require("../Store");
var Helper_1 = require("./Helper");
describe('Store foreign method', function () {
    var store;
    var model = { path: 'path' };
    var data = [{ id: 1 }];
    var instances = [{ key: function () { return data[0].id; } }];
    beforeEach(function () {
        store = new Store_1.default(null);
        store.make = jest.fn().mockReturnValue(instances);
        store.http = Helper_1.default.http(data);
    });
    it('should verify access', function () {
        store.denies = ['foreign'];
        expect(function () { return store.foreign(model, 1); }).toThrowError();
    });
    it('should skip access verification', function () {
        store.denies = ['foreign'];
        expect(function () { return store.foreign(model, 1, { permit: true }); }).not.toThrow();
    });
    it('should fetch from http request', function () {
        store.foreign(model, 1);
        expect(store.http().get).toHaveBeenCalledWith('1/path');
    });
    it('should return cached promise', function () {
        store.cache.setPromise('foreign/1/path', 'promise');
        expect(store.foreign(model, 1)).toBe('promise');
    });
    it('should fetch from cache', function () {
        store.cache.setList('1/path', instances);
        store.foreign(model, 1).then(function (result) { return expect(result).toBe(instances); });
        expect(store.http().get).not.toHaveBeenCalled();
    });
    it('should ignore cache', function () {
        store.cache.setList('foreign', instances);
        store.foreign(model, 1, { ignoreCache: true });
        expect(store.http().get).toHaveBeenCalledWith('1/path');
    });
    it('should fetch with custom url', function () {
        store.foreign(model, 1, { url: 'customUrl' });
        expect(store.http().get).toHaveBeenCalledWith('customUrl');
    });
    it('should convert result to list of model instances', function () {
        store.foreign(model, 1);
        expect(store.make).toHaveBeenCalledWith(data);
    });
    it('should add list to cache', function () {
        store.foreign(model, 1);
        expect(store.cache.getList('1/path')).toBeTruthy();
    });
    it('should add model to cache', function () {
        store.cache.set = jest.fn();
        store.foreign(model, 1, { set: true });
        expect(store.cache.set).toHaveBeenCalledWith(instances, false);
    });
    it('should not add model to cache', function () {
        store.cache.set = jest.fn();
        store.foreign(model, 1);
        expect(store.cache.set).not.toHaveBeenCalled();
    });
    it('should resolve model instances', function () {
        store.foreign(model, 1).then(function (result) {
            expect(result).toBe(instances);
        });
    });
});
//# sourceMappingURL=Foreign.spec.js.map