"use strict";
var Store_1 = require("../Store");
var Helper_1 = require("./Helper");
describe('Store get method', function () {
    var store;
    var instance = { key: function () { return 1; } };
    beforeEach(function () {
        store = new Store_1.default(null);
        store.make = jest.fn().mockReturnValue(instance);
        store.http = Helper_1.default.http('data');
    });
    it('should verify access', function () {
        store.denies = ['get'];
        expect(function () { return store.get(1); }).toThrowError();
    });
    it('should skip access verification', function () {
        store.denies = ['get'];
        expect(function () { return store.get(1, { permit: true }); }).not.toThrow();
    });
    it('should fetch from http request', function () {
        store.get(1);
        expect(store.http().get).toHaveBeenCalledWith('1');
    });
    it('should return cached promise', function () {
        store.cache.setPromise('get/1', 'promise');
        expect(store.get(1)).toBe('promise');
    });
    it('should fetch from cache', function () {
        store.cache.set(instance);
        store.get(1).then(function (result) { return expect(result).toBe(instance); });
        expect(store.http().get).not.toHaveBeenCalled();
    });
    it('should ignore cache', function () {
        store.cache.set(instance);
        store.get(1, { ignoreCache: true });
        expect(store.http().get).toHaveBeenCalledWith('1');
    });
    it('should fetch with custom url', function () {
        store.get(1, { url: 'customUrl' });
        expect(store.http().get).toHaveBeenCalledWith('customUrl');
    });
    it('should convert result to model instance', function () {
        store.get(1);
        expect(store.make).toHaveBeenCalledWith('data');
    });
    it('should add to cache', function () {
        store.get(1);
        expect(store.cache.get('1')).toBeTruthy();
    });
    it('should resolve model instance', function () {
        store.get(1).then(function (result) {
            expect(result).toBe(instance);
        });
    });
});
//# sourceMappingURL=Get.spec.js.map