"use strict";
var Store_1 = require("../Store");
var Helper_1 = require("./Helper");
describe('Store index method', function () {
    var store;
    var data = [{ id: 1 }];
    var instances = [{ key: function () { return data[0].id; } }];
    beforeEach(function () {
        store = new Store_1.default(null);
        store.make = jest.fn().mockReturnValue(instances);
        store.http = Helper_1.default.http(data);
    });
    it('should verify access', function () {
        store.denies = ['index'];
        expect(function () { return store.index(); }).toThrowError();
    });
    it('should skip access verification', function () {
        store.denies = ['index'];
        expect(function () { return store.index({ permit: true }); }).not.toThrow();
    });
    it('should fetch from http request', function () {
        store.index();
        expect(store.http().get).toHaveBeenCalledWith('');
    });
    it('should return cached promise', function () {
        store.cache.setPromise('index', 'promise');
        expect(store.index()).toBe('promise');
    });
    it('should fetch from cache', function () {
        store.cache.setList('index', instances);
        store.index().then(function (result) { return expect(result).toBe(instances); });
        expect(store.http().get).not.toHaveBeenCalled();
    });
    it('should ignore cache', function () {
        store.cache.setList('index', instances);
        store.index({ ignoreCache: true });
        expect(store.http().get).toHaveBeenCalledWith('');
    });
    it('should fetch with custom url', function () {
        store.index({ url: 'customUrl' });
        expect(store.http().get).toHaveBeenCalledWith('customUrl');
    });
    it('should convert result to list of model instances', function () {
        store.index();
        expect(store.make).toHaveBeenCalledWith(data);
    });
    it('should add list to cache', function () {
        store.index();
        expect(store.cache.getList('index')).toBeTruthy();
    });
    it('should add model to cache', function () {
        store.cache.set = jest.fn();
        store.setIndex = true;
        store.index();
        expect(store.cache.set).toHaveBeenCalledWith(instances, false);
    });
    it('should not add model to cache', function () {
        store.cache.set = jest.fn();
        store.index();
        expect(store.cache.set).not.toHaveBeenCalled();
    });
    it('should resolve model instances', function () {
        store.index().then(function (result) {
            expect(result).toBe(instances);
        });
    });
});
//# sourceMappingURL=Index.spec.js.map