"use strict";
var Helper_1 = require("./Helper");
var Store_1 = require("../Store");
describe('Store update method', function () {
    var store;
    var data = { id: 1, name: 'name' };
    var responseData = { id: 1, name: 'name', property: 'value' };
    var instance = [{ key: function () { return responseData.id; } }];
    beforeEach(function () {
        store = new Store_1.default({ keyColumn: 'id' });
        store.make = jest.fn().mockReturnValue(instance);
        store.http = Helper_1.default.http(responseData);
    });
    it('should verify access', function () {
        store.denies = ['update'];
        expect(function () { return store.update(data); }).toThrowError();
    });
    it('should make http request', function () {
        store.update(data);
        expect(store.http().put).toHaveBeenCalledWith('1', data);
    });
    it('should request with custom url', function () {
        store.update(data, { url: 'customUrl' });
        expect(store.http().put).toHaveBeenCalledWith('customUrl', data);
    });
    it('should convert result to model instance', function () {
        store.update(data);
        expect(store.make).toHaveBeenCalledWith(responseData);
    });
    it('should add model to cache', function () {
        store.cache.set = jest.fn();
        store.update(data);
        expect(store.cache.set).toHaveBeenCalledWith(instance);
    });
    it('should resolve model instance', function () {
        store.index().then(function (result) {
            expect(result).toBe(instance);
        });
    });
});
//# sourceMappingURL=Update.spec.js.map