"use strict";
var Store_1 = require("../Store");
var Helper_1 = require("./Helper");
describe('Store where method', function () {
    var store;
    var instance = { key: function () { return 'id'; }, property: 'value' };
    beforeEach(function () {
        store = new Store_1.default(null);
        store.make = jest.fn().mockReturnValue(instance);
        store.http = Helper_1.default.http('data');
    });
    it('should verify access', function () {
        store.denies = ['where'];
        expect(function () { return store.where('property', 'value'); }).toThrowError();
    });
    it('should skip access verification', function () {
        store.denies = ['where'];
        expect(function () { return store.where('property', 'value', { permit: true }); }).not.toThrow();
    });
    it('should fetch from http request', function () {
        store.where('property', 'value');
        expect(store.http().get).toHaveBeenCalledWith('property/value');
    });
    it('should return cached promise', function () {
        store.cache.setPromise('where/property/value', 'promise');
        expect(store.where('property', 'value')).toBe('promise');
    });
    it('should fetch from cache', function () {
        store.cache.set(instance);
        store.where('property', 'value').then(function (result) { return expect(result).toBe(instance); });
        expect(store.http().get).not.toHaveBeenCalled();
    });
    it('should ignore cache', function () {
        store.cache.set(instance);
        store.where('property', 'value', { ignoreCache: true });
        expect(store.http().get).toHaveBeenCalledWith('property/value');
    });
    it('should fetch with custom url', function () {
        store.where('property', 'value', { url: 'customUrl' });
        expect(store.http().get).toHaveBeenCalledWith('customUrl');
    });
    it('should convert result to model instance', function () {
        store.where('property', 'value');
        expect(store.make).toHaveBeenCalledWith('data');
    });
    it('should add to cache', function () {
        store.where('property', 'value');
        expect(store.cache.where('property', 'value')).toBeTruthy();
    });
    it('should resolve model instance', function () {
        store.where('property', 'value').then(function (result) {
            expect(result).toBe(instance);
        });
    });
});
//# sourceMappingURL=Where.spec.js.map